# PygamePal

A library of classes and functions to support game development in Pygame.
- Simple, beginner-friendly interface.
- Choose the bits you want to use, and continue to use Pygame for everything else!

### Usage

- Install: `pip install pygamepal`, or
- Install from local source: `pip install -e [repo path]`

[Add suggestions and bugs here!](https://github.com/rik-cross/pygamepal/issues)

### Getting started

- See the [Documentation](https://pygamepal.readthedocs.io/en/latest/) on readthedocs.org.
- See the simple [examples](examples/) of functionality used (mostly) individually.
- See the [Full example](examples/fullExample.py), using lots of PygamePal functionality.

### Licence

Distributed under the MIT License. See [LICENSE](LICENSE) for more information.